API Reference
=============

illico package
--------------

.. automodule:: illico.asymptotic_wilcoxon
   :members: asymptotic_wilcoxon
   :undoc-members:
   :show-inheritance:

ovo subpackage
--------------

.. automodule:: illico.ovo.dense_ovo
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: illico.ovo.sparse_ovo
   :members:
   :undoc-members:
   :show-inheritance:

ovr subpackage
--------------

.. automodule:: illico.ovr.dense_ovr
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: illico.ovr.sparse_ovr
   :members:
   :undoc-members:
   :show-inheritance:

utils
-----

.. automodule:: illico.utils.compile
   :members:
   :undoc-members:

.. automodule:: illico.utils.groups
   :members:
   :undoc-members:

.. automodule:: illico.utils.math
   :members:
   :undoc-members:

.. automodule:: illico.utils.memory
   :members:
   :undoc-members:

.. automodule:: illico.utils.ranking
   :members:
   :undoc-members:

.. automodule:: illico.utils.registry
   :members:
   :undoc-members:

.. automodule:: illico.utils.type
   :members:
   :undoc-members:
